# InlineResponse200HardwareEnvironments

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**cpu_cores** | **int** | Number of cores of the CPU. | [optional]
**cpu_family** | **int** | The CPU family. | [optional]
**cpu_model** | **int** | The CPU model. | [optional]
**cpu_model_name** | **str** | The CPU model name. | [optional]
**cpu_physical_cpus** | **int** | The CPU physical CPUs. | [optional]
**cpu_vendor** | **int** | The CPU vendor. | [optional]
**gpu_cores** | **int** | Number of cores of the GPU. | [optional]
**gpu_memory_size** | **int** | The GPU memory size. | [optional]
**gpu_model_name** | **str** | The GPU model name. | [optional]
**gpu_vendor** | **str** | The GPU vendor. | [optional]
**ram_size** | **int** | The RAM size. | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

